@@ -7,12 +7,12 @@ from django.http import HttpResponse
 from wagtail.admin.edit_handlers import FieldPanel
 from wagtail.core.models import Page
 from wagtail.documents.edit_handlers import DocumentChooserPanel
-from wagtail.documents.models import Document
+from webspace.cms.models import MyDocument
 
 
 class ADocumentPage(Page):
     document = models.ForeignKey(
-        Document,
+        MyDocument,
         null=True,
         blank=True,
         on_delete=models.SET_NULL,
